@@ -23,9 +23,6 @@
  *
  */
 
-#ifndef __CLUTTER_VERSION_H__
-#define __CLUTTER_VERSION_H__
-
 #if !defined(__CLUTTER_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
 #error "Only <clutter/clutter.h> can be included directly."
 #endif
@@ -73,6 +70,9 @@
  * header.
  */
 
+#ifndef __CLUTTER_VERSION_H__
+#define __CLUTTER_VERSION_H__
+
 #include <glib.h>
 
 G_BEGIN_DECLS
@@ -89,21 +89,21 @@ G_BEGIN_DECLS
  *
  * The minor version of the Clutter library (2, if %CLUTTER_VERSION is 1.2.3)
  */
-#define CLUTTER_MINOR_VERSION   (24)
+#define CLUTTER_MINOR_VERSION   (9)
 
 /**
  * CLUTTER_MICRO_VERSION:
  *
  * The micro version of the Clutter library (3, if %CLUTTER_VERSION is 1.2.3)
  */
-#define CLUTTER_MICRO_VERSION   (2)
+#define CLUTTER_MICRO_VERSION   (16)
 
 /**
  * CLUTTER_VERSION:
  *
  * The full version of the Clutter library, like 1.2.3
  */
-#define CLUTTER_VERSION         1.24.2
+#define CLUTTER_VERSION         1.9.16
 
 /**
  * CLUTTER_VERSION_S:
@@ -111,7 +111,7 @@ G_BEGIN_DECLS
  * The full version of the Clutter library, in string form (suited for
  * string concatenation)
  */
-#define CLUTTER_VERSION_S       "1.24.2"
+#define CLUTTER_VERSION_S       "1.9.16"
 
 /**
  * CLUTTER_VERSION_HEX:
@@ -184,76 +184,6 @@ G_BEGIN_DECLS
  */
 #define CLUTTER_VERSION_1_10    (G_ENCODE_VERSION (1, 10))
 
-/**
- * CLUTTER_VERSION_1_12:
- *
- * A macro that evaluates to the 1.12 version of Clutter, in a format
- * that can be used by the C pre-processor.
- *
- * Since: 1.12
- */
-#define CLUTTER_VERSION_1_12    (G_ENCODE_VERSION (1, 12))
-
-/**
- * CLUTTER_VERSION_1_14:
- *
- * A macro that evaluates to the 1.14 version of Clutter, in a format
- * that can be used by the C pre-processor.
- *
- * Since: 1.14
- */
-#define CLUTTER_VERSION_1_14    (G_ENCODE_VERSION (1, 14))
-
-/**
- * CLUTTER_VERSION_1_16:
- *
- * A macro that evaluates to the 1.16 version of Clutter, in a format
- * that can be used by the C pre-processor.
- *
- * Since: 1.16
- */
-#define CLUTTER_VERSION_1_16    (G_ENCODE_VERSION (1, 16))
-
-/**
- * CLUTTER_VERSION_1_18:
- *
- * A macro that evaluates to the 1.18 version of Clutter, in a format
- * that can be used by the C pre-processor.
- *
- * Since: 1.18
- */
-#define CLUTTER_VERSION_1_18    (G_ENCODE_VERSION (1, 18))
-
-/**
- * CLUTTER_VERSION_1_20:
- *
- * A macro that evaluates to the 1.20 version of Clutter, in a format
- * that can be used by the C pre-processor.
- *
- * Since: 1.20
- */
-#define CLUTTER_VERSION_1_20    (G_ENCODE_VERSION (1, 20))
-
-/**
- * CLUTTER_VERSION_1_22:
- *
- * A macro that evaluates to the 1.22 version of Clutter, in a format
- * that can be used by the C pre-processor.
- *
- * Since: 1.22
- */
-#define CLUTTER_VERSION_1_22    (G_ENCODE_VERSION (1, 22))
-
-/**
- * CLUTTER_VERSION_1_24:
- *
- * A macro that evaluates to the 1.24 version of Clutter, in a format
- * that can be used by the C pre-processor.
- *
- * Since: 1.24
- */
-#define CLUTTER_VERSION_1_24    (G_ENCODE_VERSION (1, 24))
-
 /* evaluates to the current stable version; for development cycles,
  * this means the next stable target
  */
@@ -284,22 +214,19 @@ G_BEGIN_DECLS
          (CLUTTER_MAJOR_VERSION == (major) && CLUTTER_MINOR_VERSION > (minor)) || \
          (CLUTTER_MAJOR_VERSION == (major) && CLUTTER_MINOR_VERSION == (minor) && CLUTTER_MICRO_VERSION >= (micro)))
 
-#ifndef _CLUTTER_EXTERN
-#define _CLUTTER_EXTERN extern
-#endif
-
-#ifdef CLUTTER_WINDOWING_WIN32
+/* annotation for exported variables
+ *
+ * XXX: this has to be defined here because clutter-macro.h imports this
+ * header file.
+ */
+#ifdef _MSC_VER
 # ifdef CLUTTER_COMPILATION
-#  ifdef DLL_EXPORT
-#   define CLUTTER_VAR __declspec(dllexport)
-#  else
-#   define CLUTTER_VAR extern
-#  endif
+#  define CLUTTER_VAR __declspec(dllexport)
 # else
-#  define CLUTTER_VAR __declspec(dllimport)
+#  define CLUTTER_VAR extern __declspec(dllimport)
 # endif
 #else
-# define CLUTTER_VAR _CLUTTER_EXTERN
+# define CLUTTER_VAR extern
 #endif
 
 /**
@@ -344,6 +271,12 @@ CLUTTER_VAR const guint clutter_minor_version;
  */
 CLUTTER_VAR const guint clutter_micro_version;
 
+gboolean clutter_check_version (guint major,
+                                guint minor,
+                                guint micro);
+
+gboolean clutter_check_windowing_backend (const char *backend_type);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_VERSION_H__ */
